@@ -32,7 +32,7 @@ ProbabilitySplittingRule::ProbabilitySplittingRule(size_t max_num_unique_values,
   this->imbalance_penalty = imbalance_penalty;
 
   this->counter = new size_t[max_num_unique_values];
-  this->counter_per_class = new size_t[num_classes * max_num_unique_values];
+  this->counter_per_class = new double[num_classes * max_num_unique_values];
 }
 
 ProbabilitySplittingRule::~ProbabilitySplittingRule() {
@@ -47,19 +47,20 @@ ProbabilitySplittingRule::~ProbabilitySplittingRule() {
 bool ProbabilitySplittingRule::find_best_split(const Data& data,
                                                size_t node,
                                                const std::vector<size_t>& possible_split_vars,
-                                               const std::vector<double>& responses_by_sample,
+                                               const Eigen::ArrayXXd& responses_by_sample,
                                                const std::vector<std::vector<size_t>>& samples,
                                                std::vector<size_t>& split_vars,
                                                std::vector<double>& split_values,
                                                std::vector<bool>& send_missing_left) {
   size_t size_node = samples[node].size();
-  size_t min_child_size = std::max<size_t>(std::ceil(size_node * alpha), 1uL);
+  size_t min_child_size = std::max<size_t>(static_cast<size_t>(std::ceil(size_node * alpha)), 1uL);
 
-  size_t* class_counts = new size_t[num_classes]();
+  double* class_counts = new double[num_classes]();
   for (size_t i = 0; i < size_node; ++i) {
     size_t sample = samples[node][i];
-    uint sample_class = (uint) std::round(responses_by_sample[sample]);
-    ++class_counts[sample_class];
+    uint sample_class = (uint) std::round(responses_by_sample(sample, 0));
+    double sample_weight = data.get_weight(sample);
+    class_counts[sample_class] += sample_weight;
   }
 
   // Initialize the variables to track the best split variable.
@@ -92,14 +93,14 @@ bool ProbabilitySplittingRule::find_best_split(const Data& data,
 void ProbabilitySplittingRule::find_best_split_value(const Data& data,
                                                      size_t node, size_t var,
                                                      size_t num_classes,
-                                                     size_t* class_counts,
+                                                     double* class_counts,
                                                      size_t size_node,
                                                      size_t min_child_size,
                                                      double& best_value,
                                                      size_t& best_var,
                                                      double& best_decrease,
                                                      bool& best_send_missing_left,
-                                                     const std::vector<double>& responses_by_sample,
+                                                     const Eigen::ArrayXXd& responses_by_sample,
                                                      const std::vector<std::vector<size_t>>& samples) {
   std::vector<double> possible_split_values;
   std::vector<size_t> sorted_samples;
@@ -110,27 +111,27 @@ void ProbabilitySplittingRule::find_best_split_value(const Data& data,
     return;
   }
 
-  // Initialize with 0, if not in memory efficient mode, use pre-allocated space
   size_t num_splits = possible_split_values.size() - 1;
 
   std::fill(counter_per_class, counter_per_class + num_splits * num_classes, 0);
   std::fill(counter, counter + num_splits, 0);
   size_t n_missing = 0;
-  size_t* class_counts_missing = new size_t[num_classes]();
+  double* class_counts_missing = new double[num_classes]();
 
   size_t split_index = 0;
   for (size_t i = 0; i < size_node - 1; i++) {
     size_t sample = sorted_samples[i];
     size_t next_sample = sorted_samples[i + 1];
     double sample_value = data.get(sample, var);
-    uint sample_class = responses_by_sample[sample];
+    uint sample_class = static_cast<uint>(responses_by_sample(sample, 0));
+    double sample_weight = data.get_weight(sample);
 
     if (std::isnan(sample_value)) {
-      ++class_counts_missing[sample_class];
+      class_counts_missing[sample_class] += sample_weight;
       ++n_missing;
     } else {
       ++counter[split_index];
-      ++counter_per_class[split_index * num_classes + sample_class];
+      counter_per_class[split_index * num_classes + sample_class] += sample_weight;
     }
 
     double next_sample_value = data.get(next_sample, var);
@@ -142,7 +143,7 @@ void ProbabilitySplittingRule::find_best_split_value(const Data& data,
   }
 
   size_t n_left = n_missing;
-  size_t* class_counts_left = class_counts_missing;
+  double* class_counts_left = class_counts_missing;
 
   // Compute decrease of impurity for each possible split
   for (bool send_left : {true, false}) {
@@ -178,7 +179,7 @@ void ProbabilitySplittingRule::find_best_split_value(const Data& data,
       double sum_right = 0;
       for (size_t cls = 0; cls < num_classes; ++cls) {
         class_counts_left[cls] += counter_per_class[i * num_classes + cls];
-        size_t class_count_right = class_counts[cls] - class_counts_left[cls];
+        double class_count_right = class_counts[cls] - class_counts_left[cls];
 
         sum_left += class_counts_left[cls] * class_counts_left[cls];
         sum_right += class_count_right * class_count_right;
